@@ -324,7 +324,8 @@ langcodes_t language[] = {
   { N_("North American Indian (Other)"), "nai", "nai", ""},
   { N_("Northern Sami"), "sme", "sme", "se"},
   { N_("Norwegian"), "nor", "nor", "no"},
-  { N_("Norwegian Bokml"), "nob", "nob", "nb"},
+  /* TRANSLATORS: this is really Bokm&#229;l */
+  { N_("Norwegian Bokmal"), "nob", "nob", "nb"},
   { N_("Norwegian Nynorsk"), "nno", "nno", "nn"},
   { N_("Nubian languages"), "nub", "nub", ""},
   { N_("Nyamwezi"), "nym", "nym", ""},
@@ -332,7 +333,6 @@ langcodes_t language[] = {
   { N_("Nyankole"), "nyn", "nyn", ""},
   { N_("Nyoro"), "nyo", "nyo", ""},
   { N_("Nzima"), "nzi", "nzi", ""},
-  { N_("Occitan (post 1500); Provenal"), "oci", "oci", "oc"},
   { N_("Ojibwa"), "oji", "oji", ""},
   { N_("Oriya"), "ori", "ori", "or"},
   { N_("Oromo"), "orm", "orm", "om"},
@@ -355,8 +355,10 @@ langcodes_t language[] = {
   { N_("Polish"), "pol", "pol", "pl"},
   { N_("Portuguese"), "por", "por", "pt"},
   { N_("Prakrit languages"), "pra", "pra", ""},
-  { N_("Provenal; Occitan (post 1500) "), "oci", "oci", "oc"},
-  { N_("Provenal, Old (to 1500)"), "pro", "pro", ""},
+  /* TRANSLATORS: this is really Proven&#231;al */
+  { N_("Provencal; Occitan (post 1500) "), "oci", "oci", "oc"},
+  /* TRANSLATORS: this is really Proven&#231;al */
+  { N_("Provencal, Old (to 1500)"), "pro", "pro", ""},
   { N_("Pushto"), "pus", "pus", "ps"},
   { N_("Quechua"), "que", "que", "qu"},
   { N_("Raeto-Romance"), "roh", "roh", "rm"},
@@ -457,7 +459,8 @@ langcodes_t language[] = {
   { N_("Vai"), "vai", "vai", ""},
   { N_("Venda"), "ven", "ven", ""},
   { N_("Vietnamese"), "vie", "vie", "vi"},
-  { N_("Volapk"), "vol", "vol", "vo"},
+  /* TRANSLATORS: this is really Volap&#252;k */
+  { N_("Volapuk"), "vol", "vol", "vo"},
   { N_("Votic"), "vot", "vot", ""},
   { N_("Wakashan languages"), "wak", "wak", ""},
   { N_("Walamo"), "wal", "wal", ""},
@@ -500,7 +503,7 @@ char* language_name(DVDLangID_t lang) {
   }
   fprintf(stderr, "language.language_name() Unknown language: %c%c\n",
 	  lang_code[0], lang_code[1]);
-  /* Unknown language */
+  /* TRANSLATORS: Unknown language */
   return _("Unknown");
 }
 
